@@ -35,12 +35,13 @@ class TestKenjutsu(unittest.TestCase):
 
 
     def test_reformat_slice(self):
-        with self.assertRaises(ValueError) as e:
+        with self.assertRaises(TypeError) as e:
             kenjutsu.reformat_slice(None)
 
         self.assertEqual(
             str(e.exception),
-            "Expected a `slice` type. Instead got `None`."
+            "Expected an index acceptable type."
+            " Instead got, `None`."
         )
 
         with self.assertRaises(ValueError) as e:
@@ -51,7 +52,7 @@ class TestKenjutsu(unittest.TestCase):
             "Slice cannot have a step size of `0`."
         )
 
-        with self.assertRaises(ValueError) as e:
+        with self.assertRaises(TypeError) as e:
             kenjutsu.reformat_slice([None])
 
         self.assertEqual(
@@ -195,14 +196,6 @@ class TestKenjutsu(unittest.TestCase):
 
 
     def test_reformat_slices(self):
-        with self.assertRaises(ValueError) as e:
-            kenjutsu.reformat_slices((slice(None),), (1, 2))
-
-        self.assertEqual(
-            str(e.exception),
-            "Shape must be the same as the number of slices."
-        )
-
         with self.assertRaises(ValueError) as e:
             kenjutsu.reformat_slices(
                 (slice(None), slice(None), Ellipsis), (1,)
